@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Album::Photos;
 use strict;
 use warnings;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 =head1 NAME
 
@@ -265,9 +265,9 @@ sub Gallery {
     my $where;
 
     if($cgiparams{'searchmeta'}) {
-    $cgiparams{'searchmeta'} =~ s/[,\s]+/,/g;
-    $cgiparams{'searchmeta'} = join(",", map {"'$_'"} split(",",$cgiparams{'searchmeta'}));
-    $where .= " AND m.tag IN ($cgiparams{'searchmeta'})"        if($cgiparams{'searchmeta'});
+        $cgiparams{'searchmeta'} =~ s/[,\s]+/,/g;
+        $cgiparams{'searchmeta'} = join(",", map {"'$_'"} split(",",$cgiparams{'searchmeta'}));
+        $where .= " AND m.tag IN ($cgiparams{'searchmeta'})"        if($cgiparams{'searchmeta'});
     }
 
     my @rows = $dbi->GetQuery('hash',$key.'Gallery',{where=>$where},$start);
@@ -281,7 +281,7 @@ sub Gallery {
 }
 
 sub Albums {
-    next unless($cgiparams{'pages'});
+    return  unless($cgiparams{'pages'});
     my @pages = split(',',$cgiparams{'pages'});
     for my $page (@pages) {
         $cgiparams{pageid} = $page;
